<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DimAligned</name>
    <message>
        <location filename="../DimAligned.js" line="+60"/>
        <source>First extension line origin</source>
        <translation>第一尺寸界线的起点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Second extension line origin</source>
        <translation>第二尺寸界线的起点</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Dimension line location</source>
        <translation>尺寸线位置</translation>
    </message>
    <message>
        <location filename="../DimAlignedInit.js" line="+2"/>
        <source>&amp;Aligned</source>
        <translation>对齐(&amp;A)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw aligned dimension</source>
        <translation>绘制对齐标注</translation>
    </message>
</context>
</TS>
